Learn R Programming

aniSNA (version 1.1.1)

elk_network_2010: An igraph object depicting the network obtained from elk_interactions_2010

Description

An igraph object depicting the network obtained from elk_interactions_2010

Usage

elk_network_2010

Arguments

Format

An igraph object with 57 nodes and 114 edges

Examples

Run this code
igraph::E(elk_network_2010)

Run the code above in your browser using DataLab