To convert latitude and longitude values from degrees to radians
get_coordinates_in_radian(species_raw)The same DataFrame that has been passed as the argument with two additional columns namely "latitude_rad" and "longitude_rad"
A DataFrame consisting of GPS observations. The DataFrame must have a "latitude" column and a "longitude" column whose values are specified in degrees.