Learn R Programming

aniSNA (version 1.1.1)

global_CI: To obtain confidence intervals around the observed global network statistics

Description

To obtain confidence intervals around the observed global network statistics

Usage

global_CI(
  network,
  n_versions = 100,
  network_metrics_functions_list = c(edge_density = function(x) igraph::edge_density(x),
    diameter = function(x) igraph::diameter(x, weights = NA), transitivity = function(x)
    igraph::transitivity(x)),
  CI_size = 0.95
)

Value

A DataFrame consisting of three columns. The first column contains the value of observed network metric, the second and third column represent the lower and upper limit of 95

Arguments

network

An igraph object consisting of observed network.

n_versions

Number of bootstrapped versions to be used. (default = 100)

network_metrics_functions_list

A list consisting of function definitions of the network metrics that the user wants to evaluate. Each element in the list should have an assigned name. Default = c("edge_density" = function(x) igraph::edge_density(x), "diameter" = function(x) igraph::diameter(x, weights = NA), "transitivity" = function(x) igraph::transitivity(x))

CI_size

Size of confidence interval. Default is 0.95 that generates a 95% confidence interval.

Examples

Run this code
# \donttest{
data(elk_network_2010)
global_CI(elk_network_2010, n_versions = 100, 
network_metrics_functions_list = c("edge_density" = function(x) igraph::edge_density(x),
"diameter" = function(x) igraph::diameter(x, weights = NA),
"transitivity" = function(x) igraph::transitivity(x)))
# }

Run the code above in your browser using DataLab