Learn R Programming

aniSNA (version 1.1.1)

obtain_bootstrapped_samples: To obtain bootstrapped versions of a network's adjacency matrix

Description

To obtain bootstrapped versions of a network's adjacency matrix

Usage

obtain_bootstrapped_samples(
  network,
  n_nodes = igraph::gorder(network),
  n_versions = 1000,
  seed = 12345
)

Value

A list of class bootstrapped_pvalue_matrix consisting of two elements. The first element contains the adjacency matrix of the original network and the second element contains bootstrapped versions of the adjacency matrices.

Arguments

network

An igraph object

n_nodes

Number of nodes to be selected in bootstrapped versions (default : All nodes)

n_versions

Number of bootstrapped versions required

seed

seed number

Examples

Run this code
data(elk_network_2010)
obtain_bootstrapped_samples(elk_network_2010, n_versions = 100)

Run the code above in your browser using DataLab