Learn R Programming

aniSNA (version 1.1.1)

obtain_network_subsamples: To obtain sub-networks of the observed network

Description

To obtain sub-networks of the observed network

Usage

obtain_network_subsamples(
  network,
  n_subsamples = 1,
  subsampling_proportion = 0.5
)

Value

A list of size n_subsamples, where each element of the list is an igraph object representing a sub-network of the observed network.

Arguments

network

An igraph object

n_subsamples

Number of sub-networks to be obtained. (default = 1)

subsampling_proportion

A value depicting the level (in proportion) at which sub-samples to be taken. (default = 0.5). This value should lie between 0 and 1 depicting the proportion of observed nodes to be included in the sub-network.

Examples

Run this code
data(elk_network_2010)
obtain_network_subsamples(elk_network_2010, 1, 0.5)

Run the code above in your browser using DataLab