An object of class "list_permuted_networks" of size n_permutations where each element is a network of class igraph obtained by permuting raw datastream
Arguments
species_raw
A dataframe consisting of raw GPS observations
temporal_thresh
Temporal threshold in minutes
spatial_thresh
Spatial threshold
n_permutations
Number of permuted versions to obtain
n_cores
Number of cores for parallel processing with default 1