A list of class bootstrapped_pvalue_matrix consisting of two elements. The first element contains the adjacency matrix of the original network
and the second element contains bootstrapped versions of the adjacency matrices.
Arguments
network
An igraph object
n_nodes
Number of nodes to be selected in bootstrapped versions (default : All nodes)