A list of size n_subsamples, where each element of the list is an igraph object representing a sub-network of the observed network.
Arguments
network
An igraph object
n_subsamples
Number of sub-networks to be obtained. (default = 1)
subsampling_proportion
A value depicting the level (in proportion) at which sub-samples to be taken. (default = 0.5).
This value should lie between 0 and 1 depicting the proportion of observed nodes to be included in the sub-network.